@@ -16,6 +16,7 @@
 
 """A backend for the Ubuntu One Control Panel."""
 
+import collections
 import operator
 import os
 
@@ -152,9 +153,13 @@ class ControlBackend(object):
             FILE_SYNC_UNKNOWN
         * MSG_KEY: a non translatable but human readable string of the status.
 
+        Return None if we receive and invalid type in status.
+
         """
         logger.debug('sync status: %r', status)
-        if not status:
+        if not isinstance(status, collections.Mapping):
+            return None
+        elif not status:
             self.file_sync_disabled = True
             return self.STATUS_DISABLED
 
