@@ -20,6 +20,7 @@ from __future__ import division
 
 import os
 import Queue
+import sys
 import threading
 
 from PyQt4 import QtGui, QtCore
@@ -347,9 +348,17 @@ class CalculateSize(threading.Thread):
     """A thread that calculates, in the background, the size of a folder."""
 
     def __init__(self, path_name, queue):
-        self.path_name = path_name
         self.queue = queue
         self._stop = False
+        # This makes os.walk use the "bytes" version, which doesn't
+        # break with invalid unicode paths.
+        # This will only work for unicode locales (ex: LANG=es_ES.UTF-8)
+        # and will falback to as before for C and non-unicode locales.
+        try:
+            self.path_name = path_name.encode(sys.getfilesystemencoding())
+        except (UnicodeEncodeError, UnicodeDecodeError):
+            # Should never happen (haha)
+            self.path_name = path_name
 
         super(CalculateSize, self).__init__()
 
