@@ -93,6 +93,21 @@ class FileSyncStatusTestCase(BaseTestCase):
         self.assertIsInstance(self.ui.backend,
                               backend.ControlBackend)
 
+    def test_process_info_invalid_status(self):
+        """File sync status invalid, ignore event."""
+        status = {backend.STATUS_KEY: backend.FILE_SYNC_STARTING,
+                  backend.MSG_KEY: gui.FILE_SYNC_STARTING,
+                  'icon': backend.FILE_SYNC_STARTING}
+        self.ui.process_info(status)
+        self.ui.process_info(3)
+
+        actual_icon = self.ui.ui.sync_status_icon.pixmap()
+        pixmap_name = gui.icon_name_from_status(backend.FILE_SYNC_STARTING)
+        expected_icon = gui.pixmap_from_name(pixmap_name)
+        self.assertEqualPixmaps(expected_icon, actual_icon)
+        actual_text = unicode(self.ui.ui.sync_status_label.text())
+        self.assertEqual(gui.FILE_SYNC_STARTING, actual_text)
+
     def test_process_info_changed(self):
         """Backend's file sync status changed callback is connected."""
         self.assertEqual(self.ui.backend.status_changed_handler,
