@@ -22,6 +22,7 @@ import operator
 import os
 import Queue
 import shutil
+import sys
 
 from PyQt4 import QtGui
 from twisted.internet import defer
@@ -675,7 +676,7 @@ class BaseLocalFoldersTestCase(BaseTestCase):
 
     @defer.inlineCallbacks
     def setUp(self):
-        self.path = 'not-existing-dir'
+        self.path = u'not-existing-dir'
         self.expected_size = self.build_test_dir(self.path)
         self.queue = Queue.Queue()
         yield super(BaseLocalFoldersTestCase, self).setUp()
@@ -685,7 +686,8 @@ class BaseLocalFoldersTestCase(BaseTestCase):
         assert not os.path.exists(dir_path)
 
         os.makedirs(dir_path)
-        self.addCleanup(shutil.rmtree, dir_path)
+        self.addCleanup(shutil.rmtree,
+            dir_path.encode(sys.getfilesystemencoding()))
 
         total_size = 0
 
@@ -775,6 +777,31 @@ class FakedCalculateSize(object):
         self.started = True
 
 
+class CalculateSizeWithInvalidPath(CalculateSizeTestCase):
+    """Test suite for the CalculateSize thread implementation."""
+
+    def build_test_dir(self, dir_path):
+        """Build a testing directory hierarchy."""
+        total_size = super(CalculateSizeWithInvalidPath,
+                           self).build_test_dir(dir_path)
+        # Have to crete as bytes because it's an invalid path
+        a_file = os.path.join(dir_path.encode(sys.getfilesystemencoding()),
+            '\xe7\xa7')
+        with open(a_file, 'wb') as f:
+            f.write('y' * 5000)
+        total_size += os.path.getsize(a_file)
+        return total_size
+
+    def test_run(self):
+        """The run() method calculates the size for the given path."""
+        self.ui.run()
+
+        path, size = self.queue.get(block=True, timeout=0.5)
+
+        self.assertEqual(path, self.path)
+        self.assertEqual(size, self.expected_size)
+
+
 class FolderItemTestCase(BaseLocalFoldersTestCase):
     """Test suite for the FolderItem widget."""
 
