@@ -100,6 +100,18 @@ class SystrayTestCase(TestCase):
         self.assertEqual(tray.window, window)
         self.assertTrue(tray.window.isVisible())
 
+    def test_restore_window_minimized(self):
+        """Test the restore window option in the menu, with a min. window."""
+        tray = systray.TrayIcon()
+        window = FakeMainWindow()
+        # This cannot be tested with the real activateWindow
+        # because the un-minimization is done by the WM, so
+        # it has a small delay, and it fails.
+        self.patch(window, "activateWindow", self._set_called)
+        tray.window = window
+        tray.restore.trigger()
+        self.assertEqual(self._called, ((), {}))
+
     def test_delete_window(self):
         """Test deleting an existing window."""
         tray = systray.TrayIcon()
