@@ -175,3 +175,25 @@ class FakedObject(object):
             return result
 
         return faked_call_in_faked_object
+
+
+class FakeSignal(object):
+
+    """A fake PyQt signal."""
+
+    def __init__(self, *args, **kwargs):
+        """Initialize."""
+        self.target = None
+
+    def connect(self, target):
+        """Fake connect."""
+        self.target = target
+
+    def disconnect(self, *args):
+        """Fake disconnect."""
+        self.target = None
+
+    def emit(self, *args):
+        """Fake emit."""
+        if self.target:
+            self.target(*args)
