@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-
-# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -30,11 +28,11 @@ from ubuntuone.logger import LOGBACKUP, basic_formatter
 from ubuntuone.platform.xdg_base_directory import ubuntuone_log_dir
 
 
-if os.environ.get('DEBUG'):
+if os.environ.get('U1_DEBUG'):
     LOG_LEVEL = logging.DEBUG
 else:
     # Only log this level and above
-    LOG_LEVEL = logging.DEBUG  # before final release, switch to INFO
+    LOG_LEVEL = logging.INFO
 
 FILE_NAME = os.path.join(ubuntuone_log_dir, 'controlpanel.log')
 MAIN_HANDLER = RotatingFileHandler(FILE_NAME,
@@ -53,7 +51,7 @@ def setup_logging(log_domain, prefix=None):
     logger = logging.getLogger('ubuntuone.controlpanel.%s' % log_domain)
     logger.setLevel(LOG_LEVEL)
     logger.addHandler(MAIN_HANDLER)
-    if os.environ.get('DEBUG'):
+    if os.environ.get('U1_DEBUG'):
         debug_handler = logging.StreamHandler(sys.stderr)
         debug_handler.setFormatter(basic_formatter)
         logger.addHandler(debug_handler)
