@@ -1370,6 +1370,14 @@ class BackendSyncStatusTestCase(BackendBasicTestCase):
         expected_status = self.be._process_file_sync_status(status)
         self.assertEqual(self._called, ((expected_status,), {}))
 
+    def test_invalid_status_type(self):
+        """Check that the method return None with invalid types."""
+        self.be.status_changed_handler = self._set_called
+        status = 3
+        self.be.sd_client.status_changed_handler(status)
+
+        self.assertEqual(self._called, ((None,), {}))
+
 
 class BackendSyncStatusIfDisabledTestCase(BackendSyncStatusTestCase):
     """Syncdaemon state for the backend when file sync is disabled."""
