@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-
-# Authors: Alejandro J. Cura <alecu@canonical.com>
-# Authors: Natalia B. Bidart <natalia.bidart@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -24,24 +21,19 @@ import uuid
 
 from twisted.internet import defer
 from twisted.internet.defer import inlineCallbacks, returnValue
-from ubuntuone.devtools.testcase import skipIfNotOS
-# No name 'tools' in module 'ubuntuone.platform'
-# pylint: disable=E0611
 from ubuntuone.platform import tools
-# pylint: enable=E0611
 from ubuntuone.syncdaemon.interaction_interfaces import bool_str
 
 from ubuntuone.controlpanel import sd_client
-from ubuntuone.controlpanel.tests import TestCase
+from ubuntuone.controlpanel.tests import CustomError, TestCase
+
+# Instance of 'SyncDaemonTool' has no 'foo' member
+# pylint: disable=E1101
 
 
 SAMPLE_LIMITS = {'upload': 999, 'download': 838}
 
 
-class CustomError(Exception):
-    """Custom error for tests."""
-
-
 class FakedSyncDaemonTool(object):
     """Fake the SyncDaemonTool."""
 
@@ -66,9 +58,10 @@ class FakedSyncDaemonTool(object):
     called = {}
     shares = {}
     folders = {}
-    root_dir = os.path.expanduser('~/Ubuntu One')
-    shares_dir = os.path.expanduser('~/.cache/ubuntuone/shares')
-    shares_dir_link = os.path.join(root_dir, 'Shared With Me')
+    home_dir = u'/home/ñandu úser'
+    root_dir = os.path.join(home_dir, u'Ubuntu One')
+    shares_dir = os.path.join(home_dir, u'.cache/ubuntuone/shares')
+    shares_dir_link = os.path.join(root_dir, u'Shared With Me')
 
     @classmethod
     def create_share(cls, name, accepted=False, subscribed=False):
@@ -164,6 +157,10 @@ class FakedSyncDaemonTool(object):
         """Get the list of the shares "shared"/created/offered."""
         self.called['list_shared'] = None
 
+    def validate_path(self, path):
+        """Validate a path for folder creation."""
+        return path not in [f['path'] for f in self.folders.itervalues()]
+
     def create_folder(self, path):
         """Create a user defined folder in the specified path."""
         if path == '':  # simulate an error
@@ -183,14 +180,12 @@ class FakedSyncDaemonTool(object):
     @inlineCallbacks
     def subscribe_folder(self, folder_id):
         """Subscribe to a user defined folder given its id."""
-        yield self._set_folder_attr(folder_id,
-                                                   u'subscribed', True)
+        yield self._set_folder_attr(folder_id, u'subscribed', True)
 
     @inlineCallbacks
     def unsubscribe_folder(self, folder_id):
         """Unsubscribe from a user defined folder given its id."""
-        yield self._set_folder_attr(folder_id,
-                                                   u'subscribed', False)
+        yield self._set_folder_attr(folder_id, u'subscribed', False)
 
     @inlineCallbacks
     def get_folders(self):
@@ -299,6 +294,10 @@ class FakedSyncDaemonTool(object):
         """Request a rescan from scratch for volume_id."""
         self.called['rescan_from_scratch'] = volume_id
 
+    def get_home_dir(self):
+        """Return the root directory."""
+        return self.home_dir
+
     def get_root_dir(self):
         """Return the root directory."""
         return self.root_dir
@@ -311,16 +310,17 @@ class FakedSyncDaemonTool(object):
         """Return the shares link directory."""
         return self.shares_dir_link
 
-    def set_status_changed_handler(self, handler):
+    def connect_signal(self, signal_name, handler):
         """Set the handler for the status changed signal."""
-        self.called['status_changed_handler'] = handler
+        self.called[signal_name] = handler
 
 
 class BaseTestCase(TestCase):
     """Test for the syncdaemon client methods."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(BaseTestCase, self).setUp()
+        yield super(BaseTestCase, self).setUp()
         self.patch(tools, 'SyncDaemonTool', FakedSyncDaemonTool)
         self.sd = sd_client.SyncDaemonClient()
         self.sd.proxy.shares.clear()
@@ -422,8 +422,9 @@ class NotificationsTestCase(BaseTestCase):
 
     name = 'show_all_notifications'
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(NotificationsTestCase, self).setUp()
+        yield super(NotificationsTestCase, self).setUp()
         self.getter = getattr(self.sd, '%s_enabled' % self.name)
         self.enabler = getattr(self.sd, 'enable_%s' % self.name)
         self.disabler = getattr(self.sd, 'disable_%s' % self.name)
@@ -512,6 +513,19 @@ class FoldersTestCase(BaseTestCase):
         self.patch(self.sd.proxy, 'get_folders', self.fake_fail)
         yield self.assertFailure(self.sd.get_folders(), CustomError)
 
+    @inlineCallbacks
+    def test_validate_path(self):
+        """Check if a folder path is valid."""
+        path = '~/bar/baz'
+        result = yield self.sd.validate_path(path)
+
+        self.assertTrue(result)
+
+        yield self.sd.create_folder(path)
+        result = yield self.sd.validate_path(path)
+
+        self.assertFalse(result)
+
     @inlineCallbacks
     def test_create_folder(self):
         """Create a new folder."""
@@ -688,14 +702,12 @@ class FileSyncTestCase(BaseTestCase):
 
         self.assertEqual(self.sd.proxy.called['quit'], None)
 
-    @skipIfNotOS('win32', 'The tested function is only defined on windows')
     @inlineCallbacks
     def test_set_status_changed_handler(self):
         """Connect a handler to the status changed signal."""
         sample_handler = object()
         yield self.sd.set_status_changed_handler(sample_handler)
-        self.assertEqual(sample_handler,
-                   self.sd.proxy.called['status_changed_handler'])
+        self.assertEqual(sample_handler, self.sd.proxy.called['StatusChanged'])
 
 
 class BasicTestCase(BaseTestCase):
